@@ -205,8 +205,11 @@ def copyfile(src, dst, env):
     copyfile
     """
     dst = sformat(dst,env)
-    mkdirs(juspath(dst))
-    return shutil.copyfile(sformat(src,env), dst)
+    mkdirs(justpath(dst))
+    src = sformat(src,env)
+    if os.path.isfile(src):
+        return shutil.copyfile(src, dst)
+    return False
 
 def copyshp(src, dst, env):
     """
